==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/fa.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "New login location detected",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password.",
    "Suspicious Login" : "Suspicious Login",
    "New login detected" : "New login detected",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detect and warn about suspicious IPs logging into Nextcloud\n\t",
    "Suspicious login detection" : "Suspicious login detection",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address.",
    "Training data statistics" : "Training data statistics",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Classifier model statistics",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance.",
    "Precision" : "Precision",
    "Recall" : "Recall",
    "More information ↗" : "More information ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-30.0.11.tgz: nextcloud/apps/suspicious_login/l10n/fa.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "New login location detected",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password.",
    "Suspicious Login" : "Suspicious Login",
    "New login detected" : "New login detected",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Detect and warn about suspicious IPs logging into Nextcloud\n\t",
    "More information ↗" : "More information ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address.",
    "Suspicious login detection" : "Suspicious login detection",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address.",
    "Training data statistics" : "Training data statistics",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Classifier model statistics",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance.",
    "Precision" : "Precision",
    "Recall" : "Recall"
},
"nplurals=2; plural=(n > 1);");
